==> gnome-do-plugins_0.8.1.3+dfsg.orig.tar.gz: gnome-do-plugins-0.8.1.3/Alias/src/DeleteAliasAction.cs <==
/* DeleteAliasAction.cs
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using System.Collections.Generic;

using Mono.Unix;

using Do.Universe;
using Do.Platform;

namespace Alias
{
	
	class DeleteAliasAction : Act
	{
		
		public override string Name {
			get { return Catalog.GetString ("Delete Alias"); }
		}

		public override string Description {
			get { return Catalog.GetString ("Deletes an alias."); }
		}

		public override string Icon {
			get { return "gtk-delete"; }
		}

		public override IEnumerable<Type> SupportedItemTypes {
			get { yield return typeof (Item); }
		}

		public override bool SupportsItem (Item item)
		{
			return AliasItemSource.ItemHasAlias (item);
		}

		public override IEnumerable<Item> Perform (IEnumerable<Item> items, IEnumerable<Item> modItems)
		{
			foreach (Item item in items)
				AliasItemSource.Unalias (item);
			return null;
		}
	}
}

==> gnome-do-plugins_0.8.2.1+dfsg.orig.tar.gz: gnome-do-plugins-0.8.2.1/Alias/src/DeleteAliasAction.cs <==
/* DeleteAliasAction.cs
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using System.Collections.Generic;

using Mono.Addins;

using Do.Universe;
using Do.Platform;

namespace Alias
{
	
	class DeleteAliasAction : Act
	{
		public override string Name {
			get { return AddinManager.CurrentLocalizer.GetString ("Delete Alias"); }
		}

		public override string Description {
			get { return AddinManager.CurrentLocalizer.GetString ("Deletes an alias."); }
		}

		public override string Icon {
			get { return "gtk-delete"; }
		}

		public override IEnumerable<Type> SupportedItemTypes {
			get { yield return typeof (Item); }
		}

		public override bool SupportsItem (Item item)
		{
			return AliasItemSource.ItemHasAlias (item);
		}

		public override IEnumerable<Item> Perform (IEnumerable<Item> items, IEnumerable<Item> modItems)
		{
			foreach (Item item in items)
				AliasItemSource.Unalias (item);
			return null;
		}
	}
}
